@@ -87,17 +87,21 @@ setMethod(".add",
             anchor <- (anchor+1)/2      # [0,1]
             anchor[2] <- 1 - anchor[2]     # flip yalign
             ## property
-            ## can't do this for gtkEntry
-            if('xalign' %in% names(child) && class(child)[1] != "GtkEntry") 
-              child['xalign'] <- anchor[1]
-            else if('xalign' %in% names(childWidget)
-                    && class(childWidget)[1] != "GtkEntry")
-              childWidget['xalign'] <- anchor[1]
 
-            if('yalign' %in% names(child)) 
-              child['yalign'] <- anchor[2]
-            else if('yalign' %in% names(childWidget))
-              childWidget['yalign'] <- anchor[2]
+            ## in gtkstuff
+            setXYalign(child, childWidget, anchor)
+            ## names lookup seemed to take a bit of time, is try faster?
+##             ## can't do this for gtkEntry
+##             if('xalign' %in% names(child) && class(child)[1] != "GtkEntry") 
+##               child['xalign'] <- anchor[1]
+##             else if('xalign' %in% names(childWidget)
+##                     && class(childWidget)[1] != "GtkEntry")
+##               childWidget['xalign'] <- anchor[1]
+
+##             if('yalign' %in% names(child)) 
+##               child['yalign'] <- anchor[2]
+##             else if('yalign' %in% names(childWidget))
+##               childWidget['yalign'] <- anchor[2]
             
             expand <- if(is.null(theArgs$expand)) FALSE else theArgs$expand
             parent$packStart(child, expand, TRUE, 0) # expand to fill if TRUE
@@ -129,12 +133,8 @@ setMethod(".add",
             anchor <- if(is.null(theArgs$anchor)) c(.5,.5) else theArgs$anchor
             anchor <- (anchor+1)/2      # [0,1]
             anchor[2] <- 1 - anchor[2]
-            ## can't get widget, we have block here only
-            if('xalign' %in% names(child) && class(child)[1] != "GtkEntry") 
-              child['xalign'] <- anchor[1]
-
-            if('yalign' %in% names(child)) 
-              child['yalign'] <- anchor[2]
+            ## gtkstuff
+            setXYalign(child, NULL, anchor)            
             
             expand <- if(is.null(theArgs$expand)) FALSE else theArgs$expand
             parent$packStart(child, expand, TRUE, 0) # expand to fill if TRUE
